@@ -71,7 +71,7 @@ FlacFormat::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
     parameters << QStringLiteral("-acodec") << QStringLiteral("flac");
-    foreach( const Property &property, m_propertyList )
+    for( const Property &property : m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
             && configuration.property( property.name() ).type() == property.variantType() )
@@ -90,5 +90,5 @@ FlacFormat::ffmpegParameters( const Configuration &configuration ) const
 bool
 FlacFormat::verifyAvailability( const QString &ffmpegOutput ) const
 {
-    return ffmpegOutput.contains( QRegExp( QStringLiteral("^ .EA... flac +") ) );
+    return ffmpegOutput.contains( QRegularExpression( QStringLiteral("^ .EA... flac +") ) );
 }
