@@ -22,10 +22,6 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KDBusService>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#include <Kdelibs4Migration>
-#endif
 
 #include <KLocalizedString>
 
@@ -54,40 +50,6 @@ int main( int argc, char *argv[] )
 
     KCrash::initialize();
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator configMigrator(QStringLiteral("amarok"));
-    configMigrator.setConfigFiles(QStringList()
-                                  << QStringLiteral("amarokrc")
-                                  << QStringLiteral("amarok_homerc")
-                                  << QStringLiteral("amarok-appletsrc")
-                                  );
-    configMigrator.migrate();
-
-    if (configMigrator.migrate()) {
-        Kdelibs4Migration dataMigrator;
-        const QString sourceBasePath = dataMigrator.saveLocation("data", QStringLiteral("amarok"));
-        const QString targetBasePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/amarok/");
-        QString targetFilePath;
-
-        QDir sourceDir(sourceBasePath);
-        QDir targetDir(targetBasePath);
-
-        if (sourceDir.exists()) {
-            if (!targetDir.exists()) {
-                QDir().mkpath(targetBasePath);
-            }
-            QStringList fileNames = sourceDir.entryList(
-                        QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::NoSymLinks);
-            for(const QString &fileName : fileNames) {
-                targetFilePath = targetBasePath + fileName;
-                if (!QFile::exists(targetFilePath)) {
-                    QFile::copy(sourceBasePath + fileName, targetFilePath);
-                }
-            }
-        }
-    }
-#endif
-
     KAboutData aboutData( QStringLiteral("amarok"),
                           i18n( "Amarok" ),
                           QStringLiteral(AMAROK_VERSION),
