@@ -17,19 +17,15 @@
 #ifndef POPUPWIDGET_H
 #define POPUPWIDGET_H
 
-#include <KVBox>
+#include "widgets/BoxWidget.h"
 
-
-class PopupWidget : public KVBox
+class PopupWidget : public BoxWidget
 {
 public:
-    explicit PopupWidget( QWidget * anchor, const QString &name = QString() );
-    ~PopupWidget();
+    explicit PopupWidget( const QString &name = QString() );
+    ~PopupWidget() override;
 
     void reposition();
-
-private:
-    QWidget *m_anchor;
 };
 
 #endif
